package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.engine.db.auth.AbsDb;
import com.datacloudsec.engine.db.utils.SecretUtil;
import com.datacloudsec.engine.db.utils.SerializeUtil;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DbTempMapper;
import com.datacloudsec.scan.service.IDbTemp;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/DbTempService.class */
public class DbTempService implements IDbTemp {
    private DbTempMapper dbTemp = (DbTempMapper) InstanceUtil.newDaoInstance(DbTempMapper.class);

    public int searchCount(HttpSession session, String name) throws Exception {
        return this.dbTemp.searchCount(name, DataRule.getRuleWhere(session, "t_db_policies"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer offset, Integer limit) throws Exception {
        return this.dbTemp.search(name, offset, limit, DataRule.getRuleWhere(session, "t_db_policies"));
    }

    public int pSearchCount(HttpSession session, Integer id, String name, Integer level, String cve, String type, String cnnvd) throws Exception {
        if (this.dbTemp.getTemplateById(id, DataRule.getRuleWhere(session, "t_db_policies")) != null) {
            return this.dbTemp.pSearchCount(id, name, level, cve, type, cnnvd);
        }
        return 0;
    }

    public List<Map<String, Object>> pSearch(HttpSession session, Integer id, String name, Integer level, String cve, String type, String cnnvd, Integer offset, Integer limit) throws Exception {
        if (getTemplateById(session, id) != null) {
            return this.dbTemp.pSearch(id, name, level, cve, type, cnnvd, offset, limit);
        }
        return null;
    }

    public Map<String, Object> getPolilyByOid(HttpSession session, String id) throws Exception {
        return this.dbTemp.getPolilyByOid(id);
    }

    public List<Map<String, Object>> getPoliciesInter(Integer id, String name, Integer level, String cve, String type, String cnnvd) throws Exception {
        return this.dbTemp.getPoliciesInter(id, name, level, cve, type, cnnvd);
    }

    public Map<String, Object> getTemplateById(HttpSession session, Integer id) throws Exception {
        return this.dbTemp.getTemplateById(id, DataRule.getRuleWhere(session, "t_db_policies"));
    }

    public List<Map<String, Object>> getPolicies(HttpSession session) throws Exception {
        return this.dbTemp.getPolicies(DataRule.getRuleWhere(session, "t_db_policies"));
    }

    public List<Map<String, Object>> getRuleTypes() throws Exception {
        return this.dbTemp.getRuleTypes();
    }

    @Transactional
    public void addPolicy(String db_type, String rule_type, String name, Integer level, String desct, String sugg, String cve, String cnvd, String cnnvd, Float cvss2, Float cvss3, String mode, String sql, String version, String operation) throws Exception {
        PreparedStatement insert;
        if (this.dbTemp.getCountByName(name, db_type) > 0) {
            throw new UEException("策略名称【name】已存在");
        }
        String id = "005-" + db_type + "-1-";
        String maxId = this.dbTemp.getMaxIdByLikeId(id);
        int idTemp = StringUtils.isNotBlank(maxId) ? ObjectUtil.getInt(maxId.split("-")[2], 0) : 0;
        switch (ObjectUtil.getString(Integer.valueOf(idTemp), "").length()) {
            case 1:
                id = String.valueOf(id) + "00000" + (idTemp + 1);
                break;
            case 2:
                id = String.valueOf(id) + "0000" + (idTemp + 1);
                break;
            case 3:
                id = String.valueOf(id) + "000" + (idTemp + 1);
                break;
            case 4:
                id = String.valueOf(id) + "00" + (idTemp + 1);
                break;
            case 5:
                id = String.valueOf(id) + ReportService.REPORT_STATE_READY + (idTemp + 1);
                break;
            case 6:
                id = String.valueOf(id) + (idTemp + 1);
                break;
        }
        PreparedStatement insert2 = null;
        try {
            try {
                Connection con = DriverManager.getConnection("jdbc:sqlite:" + new File(Constant.CONF_DIR, "Rule2.db").getAbsolutePath());
                if (AbsDb.TYPES.containsKey(db_type)) {
                    insert = con.prepareStatement("insert into Info(ID,Mode,SQL,DBtype) values(?,?,?,?)");
                    insert.setString(1, id);
                    insert.setString(2, mode);
                    insert.setString(3, sql);
                    insert.setString(4, db_type);
                    insert.executeUpdate();
                } else {
                    insert = con.prepareStatement("insert into Info(ID,version,operation,DBtype) values(?,?,?,?)");
                    insert.setString(1, id);
                    insert.setString(2, version);
                    insert.setString(3, operation);
                    insert.setString(4, db_type);
                    insert.executeUpdate();
                }
                if (insert != null) {
                    insert.close();
                }
                if (AbsDb.TYPES.containsKey(db_type)) {
                    engineAuth(con);
                } else {
                    engineNoSql(con);
                }
                this.dbTemp.addPolicy(id, db_type, rule_type, name, level, desct, sugg, cve, cnvd, cnnvd, cvss2, cvss3);
                this.dbTemp.addPoliMid(this.dbTemp.getTempIdByDbType(db_type), id);
                this.dbTemp.addPoliMid(1, id);
                this.dbTemp.updPoliCount(db_type, level.intValue() == 1 ? 1 : null, level.intValue() == 2 ? 1 : null, level.intValue() == 3 ? 1 : null, level.intValue() == 4 ? 1 : null, level.intValue() == 5 ? 1 : null);
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            if (0 != 0) {
                insert2.close();
            }
            throw th;
        }
    }

    private void engineAuth(Connection con) throws Exception {
        PreparedStatement ps = null;
        ResultSet rs = null;
        HashMap hashMap = new HashMap();
        try {
            try {
                ps = con.prepareStatement("select ID,Mode,SQL,DBtype from Info");
                rs = ps.executeQuery();
                while (rs.next()) {
                    String dbtype = rs.getString("DBtype");
                    List<Map<String, Object>> list = (List) hashMap.get(dbtype);
                    if (list == null) {
                        list = new ArrayList<>();
                        hashMap.put(dbtype, list);
                    }
                    Map<String, Object> row = new HashMap<>();
                    row.put("id", rs.getString("ID"));
                    row.put("mode", rs.getString("Mode"));
                    row.put("sql", rs.getString("SQL"));
                    list.add(row);
                }
                if (rs != null) {
                    rs.close();
                }
                if (ps != null) {
                    ps.close();
                }
                if (con != null) {
                    con.close();
                }
                Map<String, Object> result = new HashMap<>();
                result.put("rule", hashMap);
                byte[] r = SecretUtil.symmetryEncrypt("aes", SerializeUtil.serialize(result), com.datacloudsec.engine.db.Constant.SER_PASS);
                FileUtils.writeByteArrayToFile(new File(Constant.CONF_DIR, "customDb/dbengine2"), r);
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            if (rs != null) {
                rs.close();
            }
            if (ps != null) {
                ps.close();
            }
            if (con != null) {
                con.close();
            }
            throw th;
        }
    }

    private void engineNoSql(Connection con) throws Exception {
        PreparedStatement ps = null;
        ResultSet rs = null;
        HashMap hashMap = new HashMap();
        try {
            try {
                ps = con.prepareStatement("select ID,version,operation,DBtype from Info");
                rs = ps.executeQuery();
                while (rs.next()) {
                    String dbtype = rs.getString("DBtype");
                    List<Map<String, Object>> list = (List) hashMap.get(dbtype);
                    if (list == null) {
                        list = new ArrayList<>();
                        hashMap.put(dbtype, list);
                    }
                    Map<String, Object> row = new HashMap<>();
                    row.put("id", rs.getString("ID"));
                    row.put("version", rs.getString("version"));
                    row.put("operation", rs.getString("operation"));
                    list.add(row);
                }
                if (rs != null) {
                    rs.close();
                }
                if (ps != null) {
                    ps.close();
                }
                if (con != null) {
                    con.close();
                }
                Map<String, Object> result = new HashMap<>();
                result.put("rule", hashMap);
                byte[] r = SecretUtil.symmetryEncrypt("aes", SerializeUtil.serialize(result), com.datacloudsec.engine.db.Constant.SER_PASS);
                FileUtils.writeByteArrayToFile(new File(Constant.CONF_DIR, "customDb/dbengine_noauth2"), r);
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            if (rs != null) {
                rs.close();
            }
            if (ps != null) {
                ps.close();
            }
            if (con != null) {
                con.close();
            }
            throw th;
        }
    }

    @Transactional
    public void delPolicyById(HttpSession session, String id, Integer tempId) throws Exception {
        Map<String, Object> policy = this.dbTemp.getPolilyByOid(id);
        Integer level = ObjectUtil.getInt(policy.get("level"));
        Map<String, Object> temp = this.dbTemp.getTemplateById(tempId, DataRule.getRuleWhere(session, "t_db_policies"));
        PreparedStatement del = null;
        try {
            try {
                Connection con = DriverManager.getConnection("jdbc:sqlite:" + new File(Constant.CONF_DIR, "Rule2.db").getAbsolutePath());
                del = con.prepareStatement("delete from Info where ID = ?");
                del.setString(1, id);
                del.executeUpdate();
                if (del != null) {
                    del.close();
                }
                if (AbsDb.TYPES.containsKey(ObjectUtil.getString(temp.get("dbType"), (String) null))) {
                    engineAuth(con);
                } else {
                    engineNoSql(con);
                }
                this.dbTemp.updPoliCount2(ObjectUtil.getString(temp.get("dbType"), (String) null), level.intValue() == 1 ? 1 : null, level.intValue() == 2 ? 1 : null, level.intValue() == 3 ? 1 : null, level.intValue() == 4 ? 1 : null, level.intValue() == 5 ? 1 : null);
                this.dbTemp.delPolicyById(id);
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            if (del != null) {
                del.close();
            }
            throw th;
        }
    }
}
